@@ -31,7 +31,7 @@
 #define FROG_H
 
 #include <set>
-#include "timbl/LogStream.h"
+#include "ticcutils/LogStream.h"
 #include "libfolia/foliautils.h"
 #include "frog/Configuration.h"
 
@@ -41,7 +41,7 @@ std::string& trim(std::string &str);
 
 void getFileNames( const std::string&, std::set<std::string>& );
 
-extern LogStream *theErrLog;
+extern TiCC::LogStream *theErrLog;
 
 extern int tpDebug;
 extern Configuration configuration;
