@@ -42,7 +42,7 @@ class CGNTagger {
   std::string getTagset() const { return tagset; };
  private:
   MbtAPI *tagger;  
-  LogStream *cgnLog;
+  TiCC::LogStream *cgnLog;
   int debug;
   std::string tagset;
   std::string version;
