@@ -81,7 +81,7 @@ class Mbma {
   std::vector<MBMAana> analysis;
   std::string version;
   std::string tagset;
-  LogStream *mbmaLog;
+  TiCC::LogStream *mbmaLog;
 };
 
 class MBMAana {
