@@ -45,7 +45,7 @@ class NERTagger {
   std::string getTagset() const { return tagset; };
  private:
   MbtAPI *tagger;
-  LogStream *nerLog;
+  TiCC::LogStream *nerLog;
   int debug;
   std::string version;
   std::string tagset;
