@@ -593,9 +593,9 @@ string lookupNEREntity( const vector<Word *>& mwu,
 	      *Log(theErrLog) << "found word " << v[k] << endl;
 	    }
 	    if ( first )
-	      result += "B-" + uppercase(entities[i]->cls());
+	      result += "B-" + TiCC::uppercase(entities[i]->cls());
 	    else
-	      result += "I-" + uppercase(entities[i]->cls());
+	      result += "I-" + TiCC::uppercase(entities[i]->cls());
 	    break;
 	  }
 	  else
