@@ -47,6 +47,7 @@
 
 using namespace std;
 using namespace folia;
+using namespace TiCC;
 
 PythonInterface::PythonInterface( ) {
   Py_OptimizeFlag = 1; // enable optimisation (-O) mode
@@ -848,7 +849,7 @@ void Parser::prepareParse( Sentence *sent, const string& setname,
    vector<string> roles;
    while ( getline( is, line ) ){
      vector<string> parts;
-     int num = Timbl::split_at( line, parts, " " );
+     int num = TiCC::split_at( line, parts, " " );
      if ( num > 7 ){
        if ( Timbl::stringTo<int>( parts[0] ) != cnt+1 ){
 	 *Log(theErrLog) << "confused! " << endl;
