@@ -41,6 +41,7 @@
 
 using namespace std;
 using namespace folia;
+using namespace TiCC;
 
 Mblem::Mblem(): myLex(0),punctuation( "?...,:;\\'`(){}[]%#+-_=/!" ), 
 		history(20), debug(0) {
@@ -262,7 +263,7 @@ string Mblem::Classify( Word *sword ){
     *Log(mblemLog) << "class: " << classString  << endl;
   // 1st find all alternatives
   vector<string> parts;
-  int numParts = split_at( classString, parts, "|" );
+  int numParts = TiCC::split_at( classString, parts, "|" );
   if ( numParts < 1 ){
     *Log(mblemLog) << "no alternatives found" << endl;
   }
