@@ -41,6 +41,7 @@
 
 using namespace std;
 using namespace folia;
+using namespace TiCC;
 
 const long int LEFT =  6; // left context
 const long int RIGHT = 6; // right context
@@ -106,7 +107,7 @@ void Mbma::init_cgn( const string& dir ) {
   if ( tc ){
     while( getline( tc, line) ) {
       vector<string> tmp;
-      size_t num = split_at(line, tmp, " ");
+      size_t num = TiCC::split_at(line, tmp, " ");
       if ( num < 2 ){
 	*Log(mbmaLog) << "splitting '" << line << "' failed" << endl;
 	throw ( runtime_error("panic") );
@@ -121,7 +122,7 @@ void Mbma::init_cgn( const string& dir ) {
   if ( tc1 ){
     while( getline(tc1, line) ) {
       vector<string> tmp;
-      size_t num = split_at(line, tmp, " ");
+      size_t num = TiCC::split_at(line, tmp, " ");
       if ( num == 2 )
 	TAGconv.insert( make_pair( tmp[0], tmp[1] ) ); 
     }
@@ -526,7 +527,7 @@ void Mbma::execute( const UnicodeString& word,
   classParts.resize( classes.size() );
   for ( unsigned int j=0; j< classes.size(); ++j ){
     vector<string> parts;
-    int num = split_at( classes[j], parts, "|" );
+    int num = TiCC::split_at( classes[j], parts, "|" );
     if ( num > 0 ){
       classParts[j] = parts;
       if ( num > largest_anal )
