@@ -43,6 +43,7 @@
 
 using namespace folia;
 using namespace std;
+using namespace TiCC;
 
 mwuAna::mwuAna( Word *fwrd ){
   spec = false;
@@ -125,8 +126,8 @@ bool Mwu::read_mwus( const string& fname) {
   string line;
   while( getline( mwufile, line ) ) {
     vector<string> res1, res2; //res1 has mwus and tags, res2 has ind. words
-    if ( ( split_at(line, res1, " ") == 2 ) &&
-	 ( split_at(res1[0], res2, "_") >= 2 ) ){
+    if ( ( TiCC::split_at(line, res1, " ") == 2 ) &&
+	 ( TiCC::split_at(res1[0], res2, "_") >= 2 ) ){
       string key = res2[0];
       res2.erase(res2.begin());
       MWUs.insert( make_pair( key, res2 ) );
